/*
 * Copyright 2012-2017 Red Hat, Inc.
 *
 * This file is part of Thermostat.
 *
 * Thermostat is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2, or (at your
 * option) any later version.
 *
 * Thermostat is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Thermostat; see the file COPYING.  If not see
 * <http://www.gnu.org/licenses/>.
 *
 * Linking this code with other modules is making a combined work
 * based on this code.  Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this code give
 * you permission to link this code with independent modules to
 * produce an executable, regardless of the license terms of these
 * independent modules, and to copy and distribute the resulting
 * executable under terms of your choice, provided that you also
 * meet, for each linked independent module, the terms and conditions
 * of the license of that module.  An independent module is a module
 * which is not derived from or based on this code.  If you modify
 * this code, you may extend this exception to your version of the
 * library, but you are not obligated to do so.  If you do not wish
 * to do so, delete this exception statement from your version.
 */

package com.redhat.thermostat.agent.jcmd.backend.internal;

import com.redhat.thermostat.agent.jcmd.backend.internal.model.GCStatsModel;
import com.redhat.thermostat.agent.jcmd.backend.internal.model.JCMDBinding;
import com.redhat.thermostat.commands.model.AgentRequest;
import com.redhat.thermostat.commands.model.WebSocketResponse;
import com.redhat.thermostat.jvm.overview.agent.model.VmMapperService;
import com.redhat.thermostat.lang.schema.JSONService;
import com.redhat.thermostat.lang.schema.models.Pid;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.mockito.ArgumentCaptor;

import static org.mockito.Matchers.eq;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

public class JMXReceiverTest {

    private JMXConnectionManager connectionManager;
    private JSONService json;
    private NetworkHandler networkHandler;
    private VmMapperService mapperService;
    private AgentRequest request;
    private JCMDBinding binding;

    private Pid pid;

    @Before
    public void setup() throws Exception {
        connectionManager = mock(JMXConnectionManager.class);
        json = mock(JSONService.class);
        networkHandler = mock(NetworkHandler.class);
        mapperService = mock(VmMapperService.class);
        request = mock(AgentRequest.class);

        when(request.getJvmId()).thenReturn("42");
        when(request.getSystemId()).thenReturn("0x4A");

        pid = new Pid(42);
        when(mapperService.getPid("42")).thenReturn(pid);

        binding = mock(JCMDBinding.class);
        when(connectionManager.getBindings(pid)).thenReturn(binding);
    }

    @Test
    public void testReceiverEndQueryJCMDBinding() throws Exception {

        when(binding.getGCStats()).thenReturn("abcdefghilmnopqrstuvz");
        ArgumentCaptor<String> captor = ArgumentCaptor.forClass(String.class);
        when(networkHandler.send(captor.capture(), eq("0x4A"), eq("42"))).
                thenReturn(WebSocketResponse.ResponseType.OK);

        ArgumentCaptor<GCStatsModel> captor2 = ArgumentCaptor.forClass(GCStatsModel.class);
        when(json.serialiase(captor2.capture())).thenReturn("something.json");

        JMXReceiver receiver = new JMXReceiver(connectionManager, json,
                                               mapperService, networkHandler);
        receiver.receive(request);
        verify(binding).getGCStats();

        Assert.assertEquals("something.json", captor.getValue());
        Assert.assertEquals("abcdefghilmnopqrstuvz", captor2.getValue().getPayload());
    }
}
